==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Database specific information for offline MySQL to Azure Database for MySQL migration task inputs
 * @property name Name of the database
 * @property tableMap Mapping of source to target tables
 * @property targetDatabaseName Name of target database. Note: Target database will be truncated before starting migration.
 */
public data class MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs(
    public val name: Output<String>? = null,
    public val tableMap: Output<Map<String, String>>? = null,
    public val targetDatabaseName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs =
        com.pulumi.azurenative.datamigration.inputs.MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .tableMap(
                tableMap?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .targetDatabaseName(targetDatabaseName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs].
 */
@PulumiTagMarker
public class MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var tableMap: Output<Map<String, String>>? = null

    private var targetDatabaseName: Output<String>? = null

    /**
     * @param value Name of the database
     */
    @JvmName("ldjiumwqsvdcproc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Mapping of source to target tables
     */
    @JvmName("wuwrwnkafifkepvj")
    public suspend fun tableMap(`value`: Output<Map<String, String>>) {
        this.tableMap = value
    }

    /**
     * @param value Name of target database. Note: Target database will be truncated before starting migration.
     */
    @JvmName("yuelnkvuaplbovtm")
    public suspend fun targetDatabaseName(`value`: Output<String>) {
        this.targetDatabaseName = value
    }

    /**
     * @param value Name of the database
     */
    @JvmName("pnsasgjtkrofmhvg")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Mapping of source to target tables
     */
    @JvmName("isufpancwogabgfi")
    public suspend fun tableMap(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tableMap = mapped
    }

    /**
     * @param values Mapping of source to target tables
     */
    @JvmName("rrctfmdcaxacqnle")
    public fun tableMap(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tableMap = mapped
    }

    /**
     * @param value Name of target database. Note: Target database will be truncated before starting migration.
     */
    @JvmName("fywefrrngbcrlwfx")
    public suspend fun targetDatabaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetDatabaseName = mapped
    }

    internal fun build(): MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs =
        MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs(
            name = name,
            tableMap = tableMap,
            targetDatabaseName = targetDatabaseName,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Database specific information for offline MySQL to Azure Database for MySQL migration task inputs
 * @property name Name of the database
 * @property tableMap Mapping of source to target tables
 * @property targetDatabaseName Name of target database. Note: Target database will be truncated before starting migration.
 */
public data class MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs(
    public val name: Output<String>? = null,
    public val tableMap: Output<Map<String, String>>? = null,
    public val targetDatabaseName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datamigration.inputs.MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs =
        com.pulumi.azurenative.datamigration.inputs.MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .tableMap(
                tableMap?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .targetDatabaseName(targetDatabaseName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs].
 */
@PulumiTagMarker
public class MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var tableMap: Output<Map<String, String>>? = null

    private var targetDatabaseName: Output<String>? = null

    /**
     * @param value Name of the database
     */
    @JvmName("lnfwuggmqrgyfvnf")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Mapping of source to target tables
     */
    @JvmName("fkxwjuufhehsjndu")
    public suspend fun tableMap(`value`: Output<Map<String, String>>) {
        this.tableMap = value
    }

    /**
     * @param value Name of target database. Note: Target database will be truncated before starting migration.
     */
    @JvmName("kaeyeegihcoocuyn")
    public suspend fun targetDatabaseName(`value`: Output<String>) {
        this.targetDatabaseName = value
    }

    /**
     * @param value Name of the database
     */
    @JvmName("rqnfpemjuwkpgjhl")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Mapping of source to target tables
     */
    @JvmName("lhoxbxghvopjnrxv")
    public suspend fun tableMap(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tableMap = mapped
    }

    /**
     * @param values Mapping of source to target tables
     */
    @JvmName("feylrkjufsvxeepy")
    public fun tableMap(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tableMap = mapped
    }

    /**
     * @param value Name of target database. Note: Target database will be truncated before starting migration.
     */
    @JvmName("mrbcfryckxujqgbm")
    public suspend fun targetDatabaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetDatabaseName = mapped
    }

    internal fun build(): MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs =
        MigrateMySqlAzureDbForMySqlOfflineDatabaseInputArgs(
            name = name,
            tableMap = tableMap,
            targetDatabaseName = targetDatabaseName,
        )
}
